@@ -2,7 +2,7 @@
 .. moduleauthor:: Erwin Lejeune
 """
 
-__version__ = '1.0.0'
+__version__ = '1.0.1'
 
 from nexo.client import Client
 from nexo.response_serializers import (
@@ -16,3 +16,9 @@ from nexo.response_serializers import (
     OrderResponse,
     OrderDetails,
 )
+from nexo.exceptions import (
+    NexoAPIException,
+    NotImplementedException,
+    NexoRequestException,
+    NEXO_API_ERROR_CODES
+)
